#### Use the buttons below to manually launch different optimization tasks

#### Use the button below to publish the optimized variables at the current timestamp

#### Use the buttons below to fit, predict and tune a machine learning model for testing

#### Export InfluxDB data to CSV for ML training

Export historical sensor data from InfluxDB to train ML regressor models

#### Input Runtime Parameters